/*
    Proteus RPG Engine - A flexible 3D story based RPG engine.
    Copyright (C) 2002  Sam Yatchmenoff

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#include <windows.h>
#include <GL/gl.h>
#include <iostream>
#include <stdio.h>
#include <math.h>
#include "universe.h"
#include "input.h"
#include "party.h"
#include "visuals.h"
#include "physicalobject.h"
#include "video.h"

void Universe::adventure_init() {
	change_scene(0);
}

void Universe::adventure_shutdown() {
}
	
void Universe::adventure_start() {
	glMatrixMode(GL_PROJECTION);
	glLoadIdentity();
	glFrustum(-1.0f, 1.0f, -1.0f, 1.0f, 1.0f, 3000.0f);
	glMatrixMode(GL_MODELVIEW);
	set_game_state(GS_ADVENTURE);
	cout << "Foobar22\n";
}

// This is it, the main adventure update system.  this will run various entitie scripts, update NPCs, do everything except draw stuff.
void Universe::adventure_update() {
	if(input_get_key(I_KEY_ESC) == true) {
		cout << "Received escape, quitting\n";
		game_state = GS_QUIT;
	}
	
	if(input_get_key(I_KEY_UP) == true) {
		party.set_delta(NULL);
		party.add_delta(0.0f, 0.0f, -1.0f);
		//input_set_key(I_KEY_UP, false);
	}
	if(input_get_key(I_KEY_DOWN) == true) {
		party.set_delta(NULL);
		party.add_delta(0.0f, 0.0f, 1.0f);
		//input_set_key(I_KEY_DOWN, false);
	}
	if(input_get_key(I_KEY_LEFT) == true) { 
		party.add_yaw(2.0f);  
		//input_set_key(I_KEY_LEFT, false);
	}
	if(input_get_key(I_KEY_RIGHT) == true) {      
		party.add_yaw(-2.0f);
		//input_set_key(I_KEY_RIGHT, false);
	}
	if(input_get_key(I_KEY_SPACE) == true) {
		party.set_delta(NULL);
	}
	if(input_get_key(I_KEY_A) == true) {
		party.add_location(0.0, 10.0, 0.0);
 		input_set_key(I_KEY_A, false);
	}
	if(input_get_key(I_KEY_Z) == true) {
		party.add_location(0.0, -10.0, 0.0);
		input_set_key(I_KEY_Z, false);
	}
	if(input_get_key(I_KEY_M) == true) {
		input_set_key(I_KEY_M, false);
		menu_start();
	}
  

 	// do some collision detection
	vertex3f_t partyloc;
 	party.get_location(&partyloc);
	*scenes[0];
	for(list<Resource<Object> >::iterator i = scenes[0]->objects.begin(); i != scenes[0]->objects.end(); i++) {
		vertex3f_t objloc;
		(*i)->get_location(&objloc);
		if((objloc.x > partyloc.x - 10) && (objloc.x < partyloc.x + 10) &&
			(objloc.y > partyloc.y - 10) && (objloc.y < partyloc.y + 100) &&
			(objloc.z > partyloc.z - 10) && (objloc.z < partyloc.z + 10)) {
			
			party.add_obj_to_inv(*i);
			list<Resource<Object> >::iterator tmp = i;
			tmp++;
			scenes[0]->objects.erase(i);
			i = tmp;
		}
	}
 	party.set_order(ROT_FIRST);
 	party.move();
	adventure_draw();
}


void Universe::adventure_draw() {
	// Move the camera behind the character model
	vertex3f_t party_loc;
	party.get_location(&party_loc);
	CAMERA camera;
	camera.x = 100 * sin(party.get_yaw() * 0.01745f) + party_loc.x;
	camera.y = party_loc.y + 80;
	camera.z = 100 * cos(party.get_yaw() * 0.01745f) + party_loc.z;
 
	camera.pitch = -40.0f;
	camera.roll = 0.0f;
	camera.yaw = party.get_yaw();
	video_set_camera(&camera);
  
	// Party::draw_adventure will draw the appropriate character model
	party.draw_adventure();

//	add_visual(scenes[0]->map);
	for(list<Resource<Object> >::iterator i = scenes[0]->objects.begin(); i != scenes[0]->objects.end(); i++) {
		vertex3f_t objloc;
		(*i)->get_location(&objloc);
		Model *objmodel = (*i)->get_model();
		objmodel->set_location(objloc.x, objloc.y, objloc.z);
		add_visual(objmodel);
	}
	add_visual(scenes[0]->map);
}
