/*
    Proteus RPG Engine - A flexible 3D story based RPG engine.
    Copyright (C) 2002  Sam Yatchmenoff

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#include <windows.h>

#include <iostream.h>
#include <string>
#include "character.h"
#include "resman.h"
#include "milkshape.h"
#include "tinyxml.h"
#include "main.h"

using namespace std;

int Character::load(const string &name) {
  // Should design a better, cleaner way to handle xml files (maybe not?)
#ifdef DEBUG  
	cout << "Loading character: " << name << endl;
#endif  

	string charcfg = get_module_name() + "/party/characters/" + name + ".xml";
	TiXmlDocument doc(charcfg);
	if(!doc.LoadFile()) {
		cerr << "Error loading: " << charcfg << '\n';
		return -1;
	}
	
	TiXmlNode *node;
	TiXmlText *text;

	assert(node = doc.FirstChild("Character"));
	assert(node = node->FirstChild("Description"));
	assert(node = node->FirstChild("Name"));
	assert(text = node->FirstChild()->ToText());
	description.name = text->Value();
  
	assert(node = doc.FirstChild("Character"));
	assert(node = node->FirstChild("Description"));
	assert(node = node->FirstChild("Age"));
	assert(text = node->FirstChild()->ToText());
	description.age = atoi(text->Value().c_str()); 
  
	assert(node = doc.FirstChild("Character"));
	assert(node = node->FirstChild("Attributes"));
	assert(node = node->FirstChild("Attack"));
	assert(text = node->FirstChild()->ToText());
	attributes.attack = atoi(text->Value().c_str());
	assert(node = doc.FirstChild("Character"));
	assert(node = node->FirstChild("Attributes"));
	assert(node = node->FirstChild("Defence"));
	assert(text = node->FirstChild()->ToText());
	attributes.defence = atoi(text->Value().c_str());

	assert(node = doc.FirstChild("Character"));
	assert(node = node->FirstChild("Attributes"));
	assert(node = node->FirstChild("MagicAttack"));
	assert(text = node->FirstChild()->ToText());
	attributes.magic_attack = atoi(text->Value().c_str());
  
	assert(node = doc.FirstChild("Character"));
	assert(node = node->FirstChild("Attributes"));
	assert(node = node->FirstChild("MagicDefence"));
	assert(text = node->FirstChild()->ToText());
	attributes.magic_defence = atoi(text->Value().c_str());
	
	assert(node = doc.FirstChild("Character"));
	assert(node = node->FirstChild("Attributes"));
	assert(node = node->FirstChild("Speed"));
	assert(text = node->FirstChild()->ToText());
	attributes.speed = atoi(text->Value().c_str());

	assert(node = doc.FirstChild("Character"));
	assert(node = node->FirstChild("Attributes"));
	assert(node = node->FirstChild("Constitution"));
	assert(text = node->FirstChild()->ToText());
	attributes.constitution = atoi(text->Value().c_str());

	assert(node = doc.FirstChild("Character"));
	assert(node = node->FirstChild("Status"));
	assert(node = node->FirstChild("HP"));
	assert(text = node->FirstChild()->ToText());
	status.HP = atoi(text->Value().c_str());

	assert(node = doc.FirstChild("Character"));
	assert(node = node->FirstChild("Status"));
	assert(node = node->FirstChild("MP"));
	assert(text = node->FirstChild()->ToText());
	status.MP = atoi(text->Value().c_str());

	model = Resource<Model>(get_module_name() + "/data/models/" + name + ".pmd",  Level);
}

Resource<Bitmap> Character::get_portrait_img() {
	return portrait_img;
}

Resource<Model> Character::get_model() {
	return model;
}

