/*
    Proteus RPG Engine - A flexible 3D story based RPG engine.
    Copyright (C) 2002  Sam Yatchmenoff

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#ifndef __map_h
#define __map_h

#include <GL/gl.h>
#include <vector>
#include <string>
#include "physicalobject.h"
#include "visual.h"
#include "bsp.h"
#include <SDL.h>
#include "texture.h"

using namespace  std;

class Map : public PRVisual {
 public:
  Map() {};
  int load(const string &);
	void render();
  bool check_collision(PhysicalObject *, bsp_node *cur_node = NULL);
 private:
  bsp_header header;
  bsp_plane *plane;           // lump 1
  vertex3f_t *vertex;         // lump 2
  Uint32 vis_count;           // lump 3
  bsp_vis_offset *vis_offset;
  vector<vector<bool> > vis_PVS;
  bsp_node *node;             // lump 4
  vector<pair<bsp_texinfo*, Texture*> > texinfo;  // lump 5
  bsp_face *face;             // lump 6
  Uint8 *lightmap_data;       // lump 7
  bsp_leaf *leaf;             // lump 8
  Uint16 *leaf_face;          // lump 9
  Uint16 *edge;               // lump 11, each edge is 2 Uint16's
  Uint32 *face_edge;          // lump 12

  Uint32 currentNode;

  GLuint dlist;
};

void *load_map(const string &);
void free_map(void *);

#endif

