/*
    Proteus RPG Engine - A flexible 3D story based RPG engine.
    Copyright (C) 2002  Sam Yatchmenoff

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#ifndef __milkshape_h_
#define __milkshape_h_

#include <SDL/SDL.h>
#include <GL/gl.h>
#include "types.h"
#include "texture.h"
#include "resman.h"

#ifndef WIN32
#define PACK_STRUCT __attribute__((packed))
#else
#define PACK_STRUCT
#endif

using namespace std;

struct MS3DHeader {
  char m_ID[10];
  int m_version;
} PACK_STRUCT;

struct MS3DVertex {
  char m_flags;
  float m_vertex[3];
  char m_boneID;
  char m_refCount;
} PACK_STRUCT;


struct MS3DTriangle {
  short m_flags;
  short m_vertexIndices[3];
  float m_vertexNormals[3][3];
  float m_s[3], m_t[3];
  char m_smoothingGroup;
  char m_groupIndex;
} PACK_STRUCT;

struct MS3DMaterial {
  char m_name[32];
  float m_ambient[4];
  float m_diffuse[4];
  float m_specular[4];
  float m_emissive[4];
  float m_shininess;    // 0.0f - 128.0f
  float m_transparency; // 0.0f - 1.0f
  char m_mode;  // 0, 1, 2 is unused now
  char m_texture[128];
  char m_alphamap[128];
} PACK_STRUCT;

struct MS3DJoint {
  char m_flags;
  char m_name[32];
  char m_parentName[32];
  float m_rotation[3];
  float m_translation[3];
  short m_numRotationKeyframes;
  short m_numTranslationKeyframes;
} PACK_STRUCT;

struct MS3DKeyframe {
  float m_time;
  float m_parameter[3];
} PACK_STRUCT;

struct TRIANGLE {
  float normal[3][3];
  int vertex[3];
  float s[3], t[3];
};

struct BONE {
  int a, b;  // which nodes this bone connects to node[a] to node[b]
};

struct MATERIAL {
  float ambient[4], diffuse[4], specular[4], emissive[4];
  float shininess;
  Resource<Texture> texture;
  char *texture_filename;
};

struct SKELETON {
  int num_nodes; // number of nodes
  VERTEX *node; // array of skeleton nodes
  int num_bones; // number of bones
  BONE *bone;   // array of bones
};

struct MESH {
  int num_triangles;
  int *triangle;
  int material;
};


#endif
