/*
    Proteus RPG Engine - A flexible 3D story based RPG engine.
    Copyright (C) 2002  Sam Yatchmenoff

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#ifndef __physicalobject_h_
#define __physicalobject_h_

/* PhysicalObject is the base class of ALL
   physical objects in the game world.  It
   provides movement, collision detection,
   and anything common to all physical
   objects. */

#include "types.h"

#define DELTA_FIRST 1
#define ROT_FIRST 2

class PhysicalObject {
 public:
  void get_location(vertex3f_t *);     // interface to the location
  void set_location(vertex3f_t *);
  void add_location(vertex3f_t *);     // acts like +=
  void add_location(float, float, float);

  float get_pitch();
  void set_pitch(float);
  void add_pitch(float);

  float get_roll();
  void set_roll(float);
  void add_roll(float);

  float get_yaw();
  void set_yaw(float);
  void add_yaw(float);

  float get_radius();                  // only get, radius is constant
  
  void get_delta(vertex3f_t *);             
  void set_delta(vertex3f_t *);        // if null, reset to 0s
  void add_delta(vertex3f_t *);
  void add_delta(float, float, float);

  void move();                         // location += delta
  void move_back();                    // location -= delta, called after move
 
  void set_order(int);

 protected:
  vertex3f_t location;
  float pitch, roll, yaw; 
  float radius;
  vertex3f_t delta; 
  
  /* basically, this tells delta_add where to take
     the rotation variables into consideration or not */
  int delta_rot_order;
};

#endif
