/*
    Proteus RPG Engine - A flexible 3D story based RPG engine.
    Copyright (C) 2002  Sam Yatchmenoff

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#include <windows.h>
#include <SDL_syswm.h>
#include <iostream>
#include <stdio.h>
#include <stdarg.h>
#include <GL/gl.h>
#include <GL/glu.h>
#include "text.h"

using namespace std;

static GLuint font_list;

int load_fonts() {
	SDL_SysWMinfo wm_info;
	SDL_VERSION(&wm_info.version);

	SDL_GetWMInfo(&wm_info);
	HDC hdc = GetDC(wm_info.window);

	font_list = glGenLists(255); 

	SelectObject(hdc, GetStockObject(SYSTEM_FONT));

	bool result;
	result = wglUseFontBitmaps(hdc, 0, 255, font_list);

	if(result == false) {
		cout << "Ack!\n";
	}
	return 0;
}

void print_text(const char *text) {
	if(text == NULL)
		return;
  
	//glPushAttrib(GL_LIST_BIT);
  
	glListBase(font_list);
	glCallLists(strlen(text), GL_UNSIGNED_BYTE, text);
  
	//glPopAttrib();
}

// class Text stuff:

Text::Text(int tx, int ty, float tr, float tg, float tb,
	   const char *fmt, ...) {
	char tmp[256];
  
	va_list ap;
	va_start(ap, fmt);
	vsprintf(tmp, fmt, ap);
	va_end(ap);
  
	text = tmp;
	r = tr; g = tg; b = tb;
	x = tx; y = ty;
}

void Text::render() {  
	float x2 = (float)(x - 320) / 320.0f;
	float y2 = (float)-(y - 240 + 20) / 240.0f;  // +20 to take care of the font size
  
	glPushMatrix();
	glLoadIdentity();
  
	glColor3f(r, g, b);
	glTranslatef(0.0f, 0.0f, -1.0f);
	glRasterPos2f(x2, y2);

	print_text(text.c_str());

	glPopMatrix();

	delete this;
}
