/*
    Proteus RPG Engine - A flexible 3D story based RPG engine.
    Copyright (C) 2002  Sam Yatchmenoff

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#ifndef __universe_h
#define __universe_h

#include <string>
#include "map.h"
#include "scene.h"
#include "party.h"

#define GS_QUIT 0
#define GS_ADVENTURE 1
#define GS_BATTLE 2
#define GS_MENU 3

using namespace std;

struct GameOptions {
  string module_name;      // makes copy if first 4 characters are 'BASE'
};

class Universe {
private:
	bool blarg;

	int game_state;         // adventure, battle, menu, etc. 
	string module_dirname;
	string module_name;     // the full name of the module
  
	// Scenes
	int num_scenes;         // the number of "scenes"
	int current_scene;      // index into scene_ids and scenes
	vector<Resource<Scene> > scenes; 
  
	// Game objects
	Party party;            // the one and only Party object!
	int num_npcs;
	//NPCs **npc;           // the average dairy farmer to the giant red dragon
 

	// Private Functions
	int load_module(const string &dirname); 
	int save_module();
 
public:
	Universe(GameOptions *options);
	~Universe();

	bool error();           // just after the constructor is called
 
	int big_bang();         // where it all began...
	void game_loop();
  
	void set_game_state(int state);   // a petition to god...
  
	void change_scene(int which);
  
	// SUB SYSTEMS
private:
	// adventure
	void adventure_init();
	void adventure_shutdown();
	void adventure_start();
	void adventure_update();
	void adventure_draw();

	// battle
	void battle_init();
	void battle_shutdown();
	void battle_start();
	void battle_update();
	void battle_draw();

	// in game menu
	enum { Inventory, Stats } section;
	list<Resource<Object> >::iterator cur_item;              // for inventory
	void menu_init();
	void menu_shutdown();
	void menu_start();
	void menu_update();
	void menu_update_stats();
	void menu_update_inv();
	void menu_draw_stats();
	void menu_draw_inv();
};

#endif
